<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.wpdispensary.com
 * @since      1.0.0
 *
 * @package    WPD_Heavyweights
 * @subpackage WPD_Heavyweights/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    WPD_Heavyweights
 * @subpackage WPD_Heavyweights/admin
 * @author     WP Dispensary <deviodigital@gmail.com>
 */
class WPD_Heavyweights_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in WPD_Heavyweights_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The WPD_Heavyweights_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wpd-heavyweights-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in WPD_Heavyweights_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The WPD_Heavyweights_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wpd-heavyweights-admin.js', array( 'jquery' ), $this->version, false );

	}

}

/**
 * Heavyweight Prices metabox
 *
 * Adds the Heavyweight Prices metabox to specific custom post types
 *
 * @since    1.0.0
 */
function add_heavyweightprices_metaboxes() {

	$screens = array( 'flowers' );

	foreach ( $screens as $screen ) {
		add_meta_box(
			'wpdispensary_heavyweightprices',
			__( 'Heavyweight Prices', 'wp-dispensary' ),
			'wpdispensary_heavyweightprices',
			$screen,
			'normal',
			'default'
		);
	}

}

add_action( 'add_meta_boxes', 'add_heavyweightprices_metaboxes' );

/**
 * WP Dispensary Heavyweight Prices
 */
function wpdispensary_heavyweightprices() {
	global $post;

	/** Noncename needed to verify where the data originated */
	echo '<input type="hidden" name="heavyweightpricesmeta_noncename" id="heavyweightpricesmeta_noncename" value="' .
	wp_create_nonce( plugin_basename( __FILE__ ) ) . '" />';

	/** Get the prices data if its already been entered */
	$twoounces    = get_post_meta( $post->ID, '_twoounces', true );
	$quarterpound = get_post_meta( $post->ID, '_quarterpound', true );
	$halfpound		= get_post_meta( $post->ID, '_halfpound', true );
	$onepound     = get_post_meta( $post->ID, '_onepound', true );
	$twopounds    = get_post_meta( $post->ID, '_twopounds', true );
	$threepounds  = get_post_meta( $post->ID, '_threepounds', true );
	$fourpounds   = get_post_meta( $post->ID, '_fourpounds', true );
	$fivepounds   = get_post_meta( $post->ID, '_fivepounds', true );
	$sixpounds    = get_post_meta( $post->ID, '_sixpounds', true );
	$sevenpounds  = get_post_meta( $post->ID, '_sevenpounds', true );
	$eightpounds  = get_post_meta( $post->ID, '_eightpounds', true );
	$ninepounds   = get_post_meta( $post->ID, '_ninepounds', true );
	$tenpounds    = get_post_meta( $post->ID, '_tenpounds', true );
	$elevenpounds = get_post_meta( $post->ID, '_elevenpounds', true );
	$twelvepounds = get_post_meta( $post->ID, '_twelvepounds', true );

	/** Echo out the fields */
	echo '<div class="pricebox">';
	echo '<p>2 Ounces:</p>';
	echo '<input type="text" name="_twoounces" value="' . $twoounces  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>1/4 Pound:</p>';
	echo '<input type="text" name="_quarterpound" value="' . $quarterpound  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>1/2 Pound:</p>';
	echo '<input type="text" name="_halfpound" value="' . $halfpound  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>1 Pound:</p>';
	echo '<input type="text" name="_onepound" value="' . $onepound  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>2 Pounds:</p>';
	echo '<input type="text" name="_twopounds" value="' . $twopounds  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>3 Pounds:</p>';
	echo '<input type="text" name="_threepounds" value="' . $threepounds  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>4 Pounds:</p>';
	echo '<input type="text" name="_fourpounds" value="' . $fourpounds  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>5 Pounds:</p>';
	echo '<input type="text" name="_fivepounds" value="' . $fivepounds  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>6 Pounds:</p>';
	echo '<input type="text" name="_sixpounds" value="' . $sixpounds  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>7 Pounds:</p>';
	echo '<input type="text" name="_sevenpounds" value="' . $sevenpounds  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>8 Pounds:</p>';
	echo '<input type="text" name="_eightpounds" value="' . $eightpounds  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>9 Pounds:</p>';
	echo '<input type="text" name="_ninepounds" value="' . $ninepounds  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>10 Pounds:</p>';
	echo '<input type="text" name="_tenpounds" value="' . $tenpounds  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>11 Pounds:</p>';
	echo '<input type="text" name="_elevenpounds" value="' . $elevenpounds  . '" class="widefat" />';
	echo '</div>';
	echo '<div class="pricebox">';
	echo '<p>12 Pounds:</p>';
	echo '<input type="text" name="_twelvepounds" value="' . $twelvepounds  . '" class="widefat" />';
	echo '</div>';

}

/**
 * Save the Metabox Data
 */
function wpdispensary_save_heavyweightprices_meta( $post_id, $post ) {

	/**
	 * Verify this came from the our screen and with proper authorization,
	 * because save_post can be triggered at other times
	 */
	if ( ! isset( $_POST['heavyweightpricesmeta_noncename' ] ) || ! wp_verify_nonce( $_POST['heavyweightpricesmeta_noncename'], plugin_basename( __FILE__ ) ) ) {
		return $post->ID;
	}

	/** Is the user allowed to edit the post or page? */
	if ( ! current_user_can( 'edit_post', $post->ID ) ) {
		return $post->ID;
	}

	/**
	 * OK, we're authenticated: we need to find and save the data
	 * We'll put it into an array to make it easier to loop though.
	 */

	$heavyweightprices_meta['_twoounces']    = $_POST['_twoounces'];
	$heavyweightprices_meta['_quarterpound'] = $_POST['_quarterpound'];
	$heavyweightprices_meta['_halfpound']    = $_POST['_halfpound'];
	$heavyweightprices_meta['_onepound']     = $_POST['_onepound'];
	$heavyweightprices_meta['_twopounds']    = $_POST['_twopounds'];
	$heavyweightprices_meta['_threepounds']  = $_POST['_threepounds'];
	$heavyweightprices_meta['_fourpounds']   = $_POST['_fourpounds'];
	$heavyweightprices_meta['_fivepounds']   = $_POST['_fivepounds'];
	$heavyweightprices_meta['_sixpounds']    = $_POST['_sixpounds'];
	$heavyweightprices_meta['_sevenpounds']  = $_POST['_sevenpounds'];
	$heavyweightprices_meta['_eightpounds']  = $_POST['_eightpounds'];
	$heavyweightprices_meta['_ninepounds']   = $_POST['_ninepounds'];
	$heavyweightprices_meta['_tenpounds']    = $_POST['_tenpounds'];
	$heavyweightprices_meta['_elevenpounds'] = $_POST['_elevenpounds'];
	$heavyweightprices_meta['_twelvepounds'] = $_POST['_twelvepounds'];

	/** Add values of $prices_meta as custom fields */

	foreach ( $heavyweightprices_meta as $key => $value ) { /** Cycle through the $prices_meta array! */
		if ( 'revision' === $post->post_type ) { /** Don't store custom data twice */
			return;
		}
		$value = implode( ',', (array) $value ); /** If $value is an array, make it a CSV (unlikely) */
		if ( get_post_meta( $post->ID, $key, false ) ) { /** If the custom field already has a value */
			update_post_meta( $post->ID, $key, $value );
		} else { /** If the custom field doesn't have a value */
			add_post_meta( $post->ID, $key, $value );
		}
		if ( ! $value ) { /** Delete if blank */
			delete_post_meta( $post->ID, $key );
		}
	}

}

add_action( 'save_post', 'wpdispensary_save_heavyweightprices_meta', 1, 2 ); /** Save the custom fields */

/**
 * Action Hook
 *
 * This is the file responsible for adding the heavyweight prices
 * to the menu item pricing table.
 *
 * @since    1.0.0
 */

add_action( 'wpd_pricingoutput_bottom', 'add_wpd_heavyweight_prices' );
function add_wpd_heavyweight_prices() { ?>

<?php
		$wp_dispensary_options = get_option( 'wp_dispensary_option_name' );
		if ( null === $wp_dispensary_options['wpd_currency'] ) {
			$wpd_currency = 'USD';
		} else {
			$wpd_currency = $wp_dispensary_options['wpd_currency'];
		}
		if ( null === $wp_dispensary_options['wpd_cost_phrase'] || 'Price' === $wp_dispensary_options['wpd_cost_phrase'] ) {
			$wpd_cost_phrase = 'Pricing';
		} else {
			$wpd_cost_phrase = 'Donation';
		}

		$currency_symbols = array(
			'AED' => '&#1583;.&#1573;', // ?
			'AFN' => '&#65;&#102;',
			'ALL' => '&#76;&#101;&#107;',
			'AMD' => '',
			'ANG' => '&#402;',
			'AOA' => '&#75;&#122;', // ?
			'ARS' => '&#36;',
			'AUD' => '&#36;',
			'AWG' => '&#402;',
			'AZN' => '&#1084;&#1072;&#1085;',
			'BAM' => '&#75;&#77;',
			'BBD' => '&#36;',
			'BDT' => '&#2547;', // ?
			'BGN' => '&#1083;&#1074;',
			'BHD' => '.&#1583;.&#1576;', // ?
			'BIF' => '&#70;&#66;&#117;', // ?
			'BMD' => '&#36;',
			'BND' => '&#36;',
			'BOB' => '&#36;&#98;',
			'BRL' => '&#82;&#36;',
			'BSD' => '&#36;',
			'BTN' => '&#78;&#117;&#46;', // ?
			'BWP' => '&#80;',
			'BYR' => '&#112;&#46;',
			'BZD' => '&#66;&#90;&#36;',
			'CAD' => '&#36;',
			'CDF' => '&#70;&#67;',
			'CHF' => '&#67;&#72;&#70;',
			'CLF' => '', // ?
			'CLP' => '&#36;',
			'CNY' => '&#165;',
			'COP' => '&#36;',
			'CRC' => '&#8353;',
			'CUP' => '&#8396;',
			'CVE' => '&#36;', // ?
			'CZK' => '&#75;&#269;',
			'DJF' => '&#70;&#100;&#106;', // ?
			'DKK' => '&#107;&#114;',
			'DOP' => '&#82;&#68;&#36;',
			'DZD' => '&#1583;&#1580;', // ?
			'EGP' => '&#163;',
			'ETB' => '&#66;&#114;',
			'EUR' => '&#8364;',
			'FJD' => '&#36;',
			'FKP' => '&#163;',
			'GBP' => '&#163;',
			'GEL' => '&#4314;', // ?
			'GHS' => '&#162;',
			'GIP' => '&#163;',
			'GMD' => '&#68;', // ?
			'GNF' => '&#70;&#71;', // ?
			'GTQ' => '&#81;',
			'GYD' => '&#36;',
			'HKD' => '&#36;',
			'HNL' => '&#76;',
			'HRK' => '&#107;&#110;',
			'HTG' => '&#71;', // ?
			'HUF' => '&#70;&#116;',
			'IDR' => '&#82;&#112;',
			'ILS' => '&#8362;',
			'INR' => '&#8377;',
			'IQD' => '&#1593;.&#1583;', // ?
			'IRR' => '&#65020;',
			'ISK' => '&#107;&#114;',
			'JEP' => '&#163;',
			'JMD' => '&#74;&#36;',
			'JOD' => '&#74;&#68;', // ?
			'JPY' => '&#165;',
			'KES' => '&#75;&#83;&#104;', // ?
			'KGS' => '&#1083;&#1074;',
			'KHR' => '&#6107;',
			'KMF' => '&#67;&#70;', // ?
			'KPW' => '&#8361;',
			'KRW' => '&#8361;',
			'KWD' => '&#1583;.&#1603;', // ?
			'KYD' => '&#36;',
			'KZT' => '&#1083;&#1074;',
			'LAK' => '&#8365;',
			'LBP' => '&#163;',
			'LKR' => '&#8360;',
			'LRD' => '&#36;',
			'LSL' => '&#76;', // ?
			'LTL' => '&#76;&#116;',
			'LVL' => '&#76;&#115;',
			'LYD' => '&#1604;.&#1583;', // ?
			'MAD' => '&#1583;.&#1605;.', // ?
			'MDL' => '&#76;',
			'MGA' => '&#65;&#114;', // ?
			'MKD' => '&#1076;&#1077;&#1085;',
			'MMK' => '&#75;',
			'MNT' => '&#8366;',
			'MOP' => '&#77;&#79;&#80;&#36;', // ?
			'MRO' => '&#85;&#77;', // ?
			'MUR' => '&#8360;', // ?
			'MVR' => '.&#1923;', // ?
			'MWK' => '&#77;&#75;',
			'MXN' => '&#36;',
			'MYR' => '&#82;&#77;',
			'MZN' => '&#77;&#84;',
			'NAD' => '&#36;',
			'NGN' => '&#8358;',
			'NIO' => '&#67;&#36;',
			'NOK' => '&#107;&#114;',
			'NPR' => '&#8360;',
			'NZD' => '&#36;',
			'OMR' => '&#65020;',
			'PAB' => '&#66;&#47;&#46;',
			'PEN' => '&#83;&#47;&#46;',
			'PGK' => '&#75;', // ?
			'PHP' => '&#8369;',
			'PKR' => '&#8360;',
			'PLN' => '&#122;&#322;',
			'PYG' => '&#71;&#115;',
			'QAR' => '&#65020;',
			'RON' => '&#108;&#101;&#105;',
			'RSD' => '&#1044;&#1080;&#1085;&#46;',
			'RUB' => '&#1088;&#1091;&#1073;',
			'RWF' => '&#1585;.&#1587;',
			'SAR' => '&#65020;',
			'SBD' => '&#36;',
			'SCR' => '&#8360;',
			'SDG' => '&#163;', // ?
			'SEK' => '&#107;&#114;',
			'SGD' => '&#36;',
			'SHP' => '&#163;',
			'SLL' => '&#76;&#101;', // ?
			'SOS' => '&#83;',
			'SRD' => '&#36;',
			'STD' => '&#68;&#98;', // ?
			'SVC' => '&#36;',
			'SYP' => '&#163;',
			'SZL' => '&#76;', // ?
			'THB' => '&#3647;',
			'TJS' => '&#84;&#74;&#83;', // ? TJS (guess)
			'TMT' => '&#109;',
			'TND' => '&#1583;.&#1578;',
			'TOP' => '&#84;&#36;',
			'TRY' => '&#8356;', // New Turkey Lira (old symbol used).
			'TTD' => '&#36;',
			'TWD' => '&#78;&#84;&#36;',
			'TZS' => '',
			'UAH' => '&#8372;',
			'UGX' => '&#85;&#83;&#104;',
			'USD' => '&#36;',
			'UYU' => '&#36;&#85;',
			'UZS' => '&#1083;&#1074;',
			'VEF' => '&#66;&#115;',
			'VND' => '&#8363;',
			'VUV' => '&#86;&#84;',
			'WST' => '&#87;&#83;&#36;',
			'XAF' => '&#70;&#67;&#70;&#65;',
			'XCD' => '&#36;',
			'XDR' => '',
			'XOF' => '',
			'XPF' => '&#70;',
			'YER' => '&#65020;',
			'ZAR' => '&#82;',
			'ZMK' => '&#90;&#75;', // ?
			'ZWL' => '&#90;&#36;',
		);

?>

	<?php if ( in_array( get_post_type(), array( 'flowers' ) ) ) { ?>
	<?php
		if (
			! get_post_meta( get_the_ID(), '_twoounces', true ) &&
			! get_post_meta( get_the_ID(), '_quarterpound', true ) &&
			! get_post_meta( get_the_ID(), '_halfpound', true ) &&
			! get_post_meta( get_the_ID(), '_onepound', true ) &&
			! get_post_meta( get_the_ID(), '_twopounds', true ) &&
			! get_post_meta( get_the_ID(), '_threepounds', true ) &&
			! get_post_meta( get_the_ID(), '_fourpounds', true ) &&
			! get_post_meta( get_the_ID(), '_fivepounds', true ) &&
			! get_post_meta( get_the_ID(), '_sixpounds', true ) &&
			! get_post_meta( get_the_ID(), '_sevenpounds', true ) &&
			! get_post_meta( get_the_ID(), '_eightpounds', true ) &&
			! get_post_meta( get_the_ID(), '_ninepounds', true ) &&
			! get_post_meta( get_the_ID(), '_tenpounds', true ) &&
			! get_post_meta( get_the_ID(), '_elevenpounds', true ) &&
			! get_post_meta( get_the_ID(), '_twelvepounds', true )
		) { } else {
	?>
	</tr>
	<tr><td class="wpdispensary-title" colspan="6">Heavyweight Pricing</td></tr>
	</table>
	<table class="wpdispensary-table single pricing wpd-heavyweights">
	<tr>
		<?php if ( ! get_post_meta( get_the_ID(), '_twoounces', true ) ) { } else { ?>
			<td><span>2 oz:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_twoounces', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_quarterpound', true ) ) { } else { ?>
			<td><span>1/4 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_quarterpound', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_halfpound', true ) ) { } else { ?>
			<td><span>1/2 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_halfpound', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_onepound', true ) ) { } else { ?>
			<td><span>1 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_onepound', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_twopounds', true ) ) { } else { ?>
			<td><span>2 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_twopounds', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_threepounds', true ) ) { } else { ?>
			<td><span>3 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_threepounds', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_fourpounds', true ) ) { } else { ?>
			<td><span>4 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_fourpounds', true ); ?></td>
		<?php } ?>
	</tr>
	<tr>
		<?php if ( ! get_post_meta( get_the_ID(), '_fivepounds', true ) ) { } else { ?>
			<td><span>5 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_fivepounds', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_sixpounds', true ) ) { } else { ?>
			<td><span>6 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_sixpounds', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_sevenpounds', true ) ) { } else { ?>
			<td><span>7 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_sevenpounds', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_eightpounds', true ) ) { } else { ?>
			<td><span>8 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_eightpounds', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_ninepounds', true ) ) { } else { ?>
			<td><span>9 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_ninepounds', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_tenpounds', true ) ) { } else { ?>
			<td><span>10 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_tenpounds', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_elevenpounds', true ) ) { } else { ?>
			<td><span>11 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_elevenpounds', true ); ?></td>
		<?php } ?>
		<?php if ( ! get_post_meta( get_the_ID(), '_twelvepounds', true ) ) { } else { ?>
			<td><span>12 lb:</span> <?php echo $currency_symbols[ $wpd_currency ]; ?><?php echo get_post_meta( get_the_ID(), '_twelvepounds', true ); ?></td>
		<?php } ?>
	</tr>
	<?php } ?>

	<?php } ?>

<?php }
